@@ -140,7 +140,8 @@ QString TDuration::name() const
             case DurationType::V_BREVE:     return "breve";
             case DurationType::V_LONG:      return "long";
             default:
-qDebug("TDuration::name(): invalid duration type %hhd", _val);
+qDebug("TDuration::name(): invalid duration type %d", int(_val));
+                  // fall through
             case DurationType::V_ZERO:
             case DurationType::V_INVALID:   return "";
             }
@@ -416,6 +417,9 @@ Fraction TDuration::fraction() const
 // Longest TDuration that fits into Fraction. Must fit exactly if truncate = false.
 TDuration::TDuration(const Fraction& l, bool truncate, int maxDots, DurationType maxType)
       {
+#ifdef NDEBUG
+      Q_UNUSED(truncate);
+#endif
       setType(maxType); // use maxType to avoid testing all types if you know that l is smaller than a certain DurationType
       setDots(maxDots);
       truncateToFraction(l, maxDots);
@@ -802,5 +806,18 @@ void TDuration::setType(DurationType t)
       if (_val == DurationType::V_MEASURE)
             _dots = 0;
       }
+
+//---------------------------------------------------------
+//   isValid
+//---------------------------------------------------------
+
+bool TDuration::isValid(Fraction f)
+     {
+     TDuration t;
+     t.setType(DurationType::V_LONG);
+     t.setDots(MAX_DOTS);
+     t.truncateToFraction(f, 4);
+     return ((t.fraction() - f).numerator() == 0);
+     }
 }
 
