@@ -129,18 +129,26 @@ void KeySig::layout()
       // AND style says they are not off
       // OR key sig is CMaj/Amin (in which case they are always shown)
 
-      bool naturalsOn = false;
-      Measure* prevMeas = measure() ? measure()->prevMeasure() : nullptr;
+      Measure* m           = measure();
+      Measure* prevMeasure = m ? m->prevMeasure() : nullptr;
 
-      // If we're not force hiding naturals (Continuous panel), use score style settings
-      if (!_hideNaturals)
-          naturalsOn =
-            (prevMeas && prevMeas->sectionBreak() == nullptr
-            && (score()->styleI(StyleIdx::keySigNaturals) != int(KeySigNatural::NONE) || t1 == 0) );
-
-      // Don't repeat naturals if shown in courtesy
-      if (prevMeas && prevMeas->findSegment(Segment::Type::KeySigAnnounce, measure()->tick()) != 0
-          && segment()->segmentType() != Segment::Type::KeySigAnnounce )
+      // display of naturals defaults according to style
+      bool naturalsOn = score()->styleI(StyleIdx::keySigNaturals) != int(KeySigNatural::NONE) || t1 == 0;
+      // suppress if we are hiding all naturals
+      if (_hideNaturals)
+            naturalsOn = false;
+      // suppress after section break
+      else if (prevMeasure && prevMeasure->isFinalMeasureOfSection())
+            naturalsOn = false;
+      // suppress after courtesy keysig
+      // this may or may not have actually been generated yet,
+      // and even if it has been, it might be removed later,
+      // so instead of checking for existence of courtesy keysig,
+      // check instead for the conditions that would normally trigger it
+      else if (score()->styleB(StyleIdx::genCourtesyKeysig) && showCourtesy() && m && prevMeasure && m->system() != prevMeasure->system())
+            naturalsOn = false;
+      // suppress if no staff
+      else if (track() == -1)
             naturalsOn = false;
 
       int coffset = 0;
@@ -160,7 +168,7 @@ void KeySig::layout()
                         case 1: naturals = 0x1;  break;
                         case 0: naturals = 0;    break;
                         default:
-                              qDebug("illegal t2 key %d", t2);
+                              qDebug("illegal t2 key %d", int(t2));
                               break;
                         }
                   // remove redundant naturals
@@ -199,19 +207,31 @@ void KeySig::layout()
 
       switch(t1) {
             case 7:  addLayout(SymId::accidentalSharp, xo + 6.0 * sspread, lines[6]);
+                  // fall through
             case 6:  addLayout(SymId::accidentalSharp, xo + 5.0 * sspread, lines[5]);
+                  // fall through
             case 5:  addLayout(SymId::accidentalSharp, xo + 4.0 * sspread, lines[4]);
+                  // fall through
             case 4:  addLayout(SymId::accidentalSharp, xo + 3.0 * sspread, lines[3]);
+                  // fall through
             case 3:  addLayout(SymId::accidentalSharp, xo + 2.0 * sspread, lines[2]);
+                  // fall through
             case 2:  addLayout(SymId::accidentalSharp, xo + 1.0 * sspread, lines[1]);
+                  // fall through
             case 1:  addLayout(SymId::accidentalSharp, xo,                 lines[0]);
                      break;
             case -7: addLayout(SymId::accidentalFlat, xo + 6.0 * fspread, lines[13]);
+                  // fall through
             case -6: addLayout(SymId::accidentalFlat, xo + 5.0 * fspread, lines[12]);
+                  // fall through
             case -5: addLayout(SymId::accidentalFlat, xo + 4.0 * fspread, lines[11]);
+                  // fall through
             case -4: addLayout(SymId::accidentalFlat, xo + 3.0 * fspread, lines[10]);
+                  // fall through
             case -3: addLayout(SymId::accidentalFlat, xo + 2.0 * fspread, lines[9]);
+                  // fall through
             case -2: addLayout(SymId::accidentalFlat, xo + 1.0 * fspread, lines[8]);
+                  // fall through
             case -1: addLayout(SymId::accidentalFlat, xo,                 lines[7]);
             case 0:
                   break;
