@@ -26,6 +26,7 @@
 #include "segment.h"
 #include "ottava.h"
 #include "spannermap.h"
+#include "layoutbreak.h"
 #include "rehearsalmark.h"
 #include <set>
 
@@ -397,10 +398,6 @@ class Score : public QObject, public ScoreElement {
 
       int _pos[3];            ///< 0 - current, 1 - left loop, 2 - right loop
 
-      bool _foundPlayPosAfterRepeats; ///< Temporary used during playback rendering
-                                      ///< indicating if playPos after expanded repeats
-                                      ///< has been calculated.
-
       int _fileDivision; ///< division of current loading *.mscx file
       int _mscVersion; ///< version of .mscx file during file read, then changed to MSCVERSION for drag and drop
       int _mscRealVersion;  ///< keep the actual and initial version of current loaded *.mscx file
@@ -493,6 +490,10 @@ class Score : public QObject, public ScoreElement {
       FileError read114(XmlReader&);
       FileError read1(XmlReader&, bool ignoreVersionError);
 
+      void renderStaff(EventMap* events, Staff*);
+      void renderSpanners(EventMap* events);
+      void renderMetronome(EventMap* events, Measure* m, int tickOffset);
+
    protected:
       void createPlayEvents(Chord*);
       void createGraceNotesPlayEvents(QList<Chord*> gnb, int tick, Chord* chord, int& ontime);
@@ -533,6 +534,7 @@ class Score : public QObject, public ScoreElement {
       void cmdHalfDuration()        { cmdIncDecDuration( 1, 0); }
       void cmdIncDurationDotted()   { cmdIncDecDuration(-1, 1); }
       void cmdDecDurationDotted()   { cmdIncDecDuration( 1, 1); }
+      void cmdToggleLayoutBreak(LayoutBreak::Type);
 
       void addRemoveBreaks(int interval, bool lock);
 
@@ -805,9 +807,7 @@ class Score : public QObject, public ScoreElement {
       PasteStatus pasteStaff(XmlReader&, Segment* dst, int staffIdx);
       void pasteSymbols(XmlReader& e, ChordRest* dst);
       void renderMidi(EventMap* events);
-      void renderStaff(EventMap* events, Staff*);
-      void renderSpanners(EventMap* events, int staffIdx);
-      void renderMetronome(EventMap* events, Measure* m, int tickOffset);
+      void renderMidi(EventMap* events, bool metronome, bool expandRepeats);
 
       BeatType tick2beatType(int tick);
 
@@ -869,7 +869,7 @@ class Score : public QObject, public ScoreElement {
       void adjustKeySigs(int sidx, int eidx, KeyList km);
 
       void endUndoRedo();
-      Measure* searchLabel(const QString& s);
+      Measure* searchLabel(const QString& s, Measure* startMeasure = nullptr, Measure* endMeasure = nullptr);
       Measure* searchLabelWithinSectionFirst(const QString& s, Measure* sectionStartMeasure, Measure* sectionEndMeasure);
       RepeatList* repeatList() const;
       qreal utick2utime(int tick) const;
@@ -958,13 +958,13 @@ class Score : public QObject, public ScoreElement {
       void addLayoutFlags(LayoutFlags val)               { layoutFlags |= val; }
       void updateHairpin(Hairpin*);       // add/modify hairpin to pitchOffset list
       void removeHairpin(Hairpin*);       // remove hairpin from pitchOffset list
-      Volta* searchVolta(int tick) const;
       Score* parentScore() const    { return _parentScore; }
       void setParentScore(Score* s) { _parentScore = s;    }
       const Score* rootScore() const;
       Score* rootScore();
       void addExcerpt(Score*);
       void removeExcerpt(Score*);
+
       void createRevision();
       QByteArray readCompressedToBuffer();
       QByteArray readToBuffer();
@@ -1028,7 +1028,7 @@ class Score : public QObject, public ScoreElement {
       void respace(QList<ChordRest*>* elements);
       void transposeSemitone(int semitone);
       MeasureBase* insertMeasure(Element::Type type, MeasureBase*,
-         bool createEmptyMeasures = false);
+         bool createEmptyMeasures = false, bool moveHeader = true);
       Audio* audio() const         { return _audio;    }
       void setAudio(Audio* a)      { _audio = a;       }
       PlayMode playMode() const    { return _playMode; }
