@@ -841,7 +841,7 @@ qreal StaffType::physStringToYOffset(int strg) const
       if (yOffset >= _lines) {                  // if physical string 'below' tab lines,
             yOffset = _lines;                   // reduce to first string 'below' tab body
             if (!_useNumbers)                   // with letters, add some space for the slashes ascender
-                  yOffset = _lines + STAFFTYPE_TAB_BASSSLASH_YOFFSET;
+                  yOffset = _onLines ? _lines : _lines + STAFFTYPE_TAB_BASSSLASH_YOFFSET;
             }
       // if TAB upside down, flip around top line
       yOffset = _upsideDown ? (qreal)(_lines - 1) - yOffset : yOffset;
@@ -895,9 +895,10 @@ void TabDurationSymbol::layout()
       qreal xpos, ypos;             // position coords
 
       _beamGrid = TabBeamGrid::NONE;
-      Chord* chord = static_cast<Chord*>(parent());
+      Element* el = parent();
+      Chord* chord = static_cast<Chord*>(el);
       // if no chord (shouldn't happens...) or not a special beam mode, layout regular symbol
-      if (!chord || chord->type() != Element::Type::CHORD ||
+      if (!el || el->type() != Element::Type::CHORD ||
             (chord->beamMode() != Beam::Mode::BEGIN && chord->beamMode() != Beam::Mode::MID &&
                   chord->beamMode() != Beam::Mode::END) ) {
             QFontMetricsF fm(_tab->durationFont());
