@@ -61,10 +61,8 @@ Tuplet::Tuplet(const Tuplet& t)
       _p1           = t._p1;
       _p2           = t._p2;
 
-      if (t._number)
-            _number = new Text(*t._number);
-      else
-            _number = 0;
+     // recreated on layout
+     _number = 0;
       }
 
 //---------------------------------------------------------
@@ -688,8 +686,8 @@ void Tuplet::read(XmlReader& e)
             else if (!DurationElement::readProperties(e))
                   e.unknown();
             }
-      Fraction f(_ratio.reduced().denominator(), _baseLen.fraction().denominator());
-      setDuration(f);
+      Fraction f(_ratio.denominator(), _baseLen.fraction().denominator());
+      setDuration(f.reduced());
       if (bl != -1) {         // obsolete
             TDuration d;
             d.setVal(bl);
@@ -970,5 +968,58 @@ QVariant Tuplet::propertyDefault(P_ID id) const
             }
       }
 
+//---------------------------------------------------------
+//   sanitizeTuplet
+///    Check validity of tuplets and coherence between duration
+///    and baselength. Needed for importing old files due to a bug
+///    in the released version for corner-case tuplets.
+///    See issue #136406 and Pull request #2881
+//---------------------------------------------------------
+
+void Tuplet::sanitizeTuplet()
+      {
+      if (ratio().numerator() == ratio().reduced().numerator()) // return if the ratio is an irreducible fraction
+            return;
+      Fraction baseLenDuration = (Fraction(ratio().denominator(),1) * baseLen().fraction()).reduced();
+      // Due to a bug present in 2.1 (and before), a tuplet with non-reduced ratio could be 
+      // in a corrupted state (mismatch between duration and base length).
+      // A tentative will now be made to retrieve the correct duration by summing up all the
+      // durations of the elements constituting the tuplet. This does not work for
+      // not-completely filled tuplets, such as tuplets in voices > 0 with
+      // gaps (for example, a tuplet in second voice with a deleted chordrest element)
+      Fraction testDuration(0,1);
+      for (DurationElement* de : elements()) {
+            if (de == 0)
+                  continue;
+            Fraction elementDuration(0,1);
+            if (de->type() == Element::Type::TUPLET){
+                  Tuplet* t = static_cast<Tuplet*>(de);
+                  t->sanitizeTuplet();
+                  elementDuration = t->duration();
+                  }
+            else {
+                  elementDuration = de->duration();
+                  }
+            testDuration += elementDuration;
+            }
+      testDuration = testDuration / ratio();
+      testDuration.reduce();
+      if (elements().back()->tick() + elements().back()->actualTicks() - elements().front()->tick() > testDuration.ticks())
+            return;     // this tuplet has missing elements; do not sanitize
+      if (!(testDuration == baseLenDuration && baseLenDuration == duration())) {
+            Fraction f = testDuration * Fraction(1, ratio().denominator());
+            f.reduce();
+            Fraction fbl(1, f.denominator());
+            if (TDuration::isValid(fbl)) {
+                  setDuration(testDuration);
+                  setBaseLen(fbl);
+                  qDebug("Tuplet %p sanitized",this);
+                  }
+            else {
+                  qDebug("Impossible to sanitize the tuplet");
+                  }
+            }
+      }
+
 }
 
