@@ -630,16 +630,16 @@ void ScoreView::fotoContextPopup(QContextMenuEvent* ev)
             return;
       QString cmd(a->data().toString());
       if (cmd == "print")
-            saveFotoAs(true, _foto->rect());
+            saveFotoAs(true, _foto->rect().normalized());
       else if (cmd == "screenshot")
-            saveFotoAs(false, _foto->rect());
+            saveFotoAs(false, _foto->rect().normalized());
       else if (cmd == "copy")
             ;
       else if (cmd == "set-res") {
             bool ok;
             double resolution = QInputDialog::getDouble(this,
                tr("Set Output Resolution"),
-               tr("Set output resolution for PNG/SVG"),
+               tr("Set output resolution for PNG"),
                preferences.pngResolution,
                16.0, 2400.0, 1,
                &ok
@@ -683,12 +683,11 @@ void ScoreView::fotoContextPopup(QContextMenuEvent* ev)
 
 void ScoreView::fotoModeCopy()
       {
-      // oowriter wants transparent==false
-      bool transparent = false; // preferences.pngTransparent;
+      bool transparent = preferences.pngTransparent;
       double convDpi   = preferences.pngResolution;
       double mag       = convDpi / DPI;
 
-      QRectF r(_foto->rect());
+      QRectF r(_foto->rect().normalized());
 
       int w = lrint(r.width()  * mag);
       int h = lrint(r.height() * mag);
@@ -782,6 +781,7 @@ bool ScoreView::saveFotoAs(bool printMode, const QRectF& r)
 
       if (ext == "pdf") {
             QPrinter printer(QPrinter::HighResolution);
+            printer.setOutputFormat(QPrinter::PdfFormat);
             mag = printer.logicalDpiX() / DPI;
             printer.setPaperSize(QSizeF(r.width() * mag, r.height() * mag) , QPrinter::DevicePixel);
             printer.setCreator("MuseScore Version: " VERSION);
@@ -789,10 +789,10 @@ bool ScoreView::saveFotoAs(bool printMode, const QRectF& r)
             printer.setColorMode(QPrinter::Color);
             printer.setDocName(fn);
             printer.setOutputFileName(fn);
-            if (ext == "pdf")
-                  printer.setOutputFormat(QPrinter::PdfFormat);
             QPainter p(&printer);
+            MScore::pdfPrinting = true;
             paintRect(printMode, p, r, mag);
+            MScore::pdfPrinting = false;
             }
       else if (ext == "svg") {
             // note that clipping is not implemented
