@@ -20,6 +20,7 @@
 
 #include "instrdialog.h"
 #include "musescore.h"
+#include "preferences.h"
 #include "scoreview.h"
 #include "seq.h"
 #include "libmscore/barline.h"
@@ -73,7 +74,9 @@ void InstrumentsDialog::on_saveButton_clicked()
          this,
          tr("Save Instrument List"),
          ".",
-         tr("MuseScore Instruments") + " (*.xml)"
+         tr("MuseScore Instruments") + " (*.xml)",
+         0,
+         preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog
          );
       if (name.isEmpty())
             return;
@@ -101,8 +104,8 @@ void InstrumentsDialog::on_saveButton_clicked()
             }
       xml.etag();
       if (f.error() != QFile::NoError) {
-            QString s = tr("Write Style failed: ") + f.errorString();
-            QMessageBox::critical(this, tr("Write Style"), s);
+            QString s = tr("Write Instruments File failed: ") + f.errorString();
+            QMessageBox::critical(this, tr("Write Instruments File"), s);
             }
       }
 
@@ -115,7 +118,9 @@ void InstrumentsDialog::on_loadButton_clicked()
       QString fn = QFileDialog::getOpenFileName(
          this, tr("Load Instrument List"),
           mscoreGlobalShare + "/templates",
-         tr("MuseScore Instruments") + " (*.xml)"
+         tr("MuseScore Instruments") + " (*.xml)",
+         0,
+         preferences.nativeDialogs ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog
          );
       if (fn.isEmpty())
             return;
