@@ -4,8 +4,12 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Orchestral instruments"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Early music"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Ethnic instruments"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Woodwind"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Winds"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "W.", "Winds"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Picc.", "Piccolo"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "D♭ Piccolo"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "D♭ Picc.", "D♭ Piccolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Flute"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Fl.", "Flute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Flute"),
@@ -118,8 +122,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Tin Wh.", "Tin Whistle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Whistle"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Tin Wh.", "B♭ Tin Whistle"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Tin Wh.", "Tin Whistle"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "D Tin Whistle"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "D Tin Wh.", "D Tin Whistle"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Oboe"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Ob.", "Piccolo Oboe"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe"),
@@ -138,6 +142,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Heckelphone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Hph.", "Piccolo Heckelphone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Hph.", "Heckelphone"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Lupophone"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Lph.", "Lupophone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone-clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Hph.", "Heckelphone-clarinet"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Shawm"),
@@ -226,6 +232,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "D Clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "D Cl.", "D Clarinet"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Cl.", "E♭ Clarinet"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "G Clarinet"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "G Cl.", "G Clarinet"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Cl.", "B♭ Clarinet"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "A Clarinet"),
@@ -238,6 +246,12 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Basset Horn"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Ba. Hn.", "Basset Horn"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Cl.", "Bass Clarinet"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Clarinet (Bass Clef)"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ B. Cl.", "B♭ Bass Clarinet (Bass Clef)"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Clarinet"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "A B. Cl.", "A Bass Clarinet"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Clarinet (Bass Clef)"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "A B. Cl.", "A Bass Clarinet (Bass Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contra-alto Clarinet"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "C-a. Cl.", "Contra-alto Clarinet"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Clarinet"),
@@ -838,6 +852,10 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar.", "Baritone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Bass"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "B.", "Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Women"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "W.", "Women"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Men"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "M.", "Men"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Kazoo"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Kaz.", "Kazoo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Keyboards"),
@@ -1003,10 +1021,15 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar (Treble Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Guitar"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Guit.", "Baritone Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Contra Guitar"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "C Guit.", "Contra Guitar"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "C. Guit.", "Contra Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Acoustic Guitar"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Guitar"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar (Treble Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar [Tablature]"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "11-string Alto Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "11-str. A. Guit.", "11-string Alto Guitar"),
@@ -1016,6 +1039,9 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Pedal Steel Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Ped. St. Guit.", "Pedal Steel Guitar"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "El. Guit.", "Electric Guitar"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "El. Guit.", "Electric Guitar"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar (Treble Clef)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar [Tablature]"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Harp"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Hrp.", "Harp"),
@@ -1023,6 +1049,8 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "staccato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "flageoletti"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Koto"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Ko.", "Koto"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Oud"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "O.", "Oud"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Lute [Tablature]"),
@@ -1057,9 +1085,9 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Mandolin [Tablature]"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Mandola"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Mda.", "Mandola"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Mandola"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Mda.", "Alto Mandola"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Mda.", "Alto Mandola"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Mandola"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Mda.", "Tenor Mandola"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Mda.", "Tenor Mandola"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Mandocello"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Mncl.", "Mandocello"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Octave Mandolin"),
@@ -1084,16 +1112,35 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Bass"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Bass", "Acoustic Bass"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "arco"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "Electric Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass [Tablature]"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Fretless Electric Bass"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Frtl. El. B.", "Fretless Electric Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "5-str. Electric Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass [Tablature]"),
-QT_TRANSLATE_NOOP("InstrumentsXML", "Prima"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Pr.", "Prima"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "5-str. Electric Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass (High C/Tenor)"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass (High C/Tenor) [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "6-str. Electric Bass"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "6-str. Electric Bass"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "6-str. Electric Bass [Tablature]"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Prim"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Pr.", "Prim"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Brač"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Br.", "Brač"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Čelo"),
@@ -1103,6 +1150,10 @@ QT_TRANSLATE_NOOP3("InstrumentsXML", "Bu.", "Bugarija"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Berda"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Be.", "Berda"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "St.", "Strings"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Erhu"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Eh.", "Erhu"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
@@ -1168,11 +1219,15 @@ QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tab)"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Vla. d. g.", "Viola da gamba (Tab)"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tablature)"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "Baryton"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "Bary.", "Baryton"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
+QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "Violone"),
 QT_TRANSLATE_NOOP3("InstrumentsXML", "Vne.", "Violone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "D Violone"),
-QT_TRANSLATE_NOOP3("InstrumentsXML", "Vne.", "D Violone"),
+QT_TRANSLATE_NOOP3("InstrumentsXML", "D Vne.", "D Violone"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
 QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
